From: Nicholas Piggin <npiggin@gmail.com>
To: Masahiro Yamada <yamada.masahiro@socionext.com>
Cc: Linux Kbuild mailing list <linux-kbuild@vger.kernel.org>,
Linux Kernel Mailing List <linux-kernel@vger.kernel.org>,
Stephen Rothwell <sfr@canb.auug.org.au>
Subject: Re: [PATCH 1/2] kbuild: remove top-level built-in.a
Date: Wed, 23 Jan 2019 18:26:35 +1000 [thread overview]
Message-ID: <1548231946.lwdxf373y2.astroid@bobo.none> (raw)
In-Reply-To: <CAK7LNAREyw=qhRO-Cvg4O2fOnbV=zVJDE_mRZcVTkKG+B1gkRQ@mail.gmail.com>
Masahiro Yamada's on January 15, 2019 7:01 pm:
> Hi Nicholas,
>
>
> On Tue, Jan 15, 2019 at 5:07 PM Nicholas Piggin <npiggin@gmail.com> wrote:
>>
>> Masahiro Yamada's on January 14, 2019 1:27 pm:
>> > The symbol table in the final archive is unneeded because it is passed
>> > to the linker after the --whole-archive option. Every object file in
>> > the archive is included in the link anyway.
>> >
>> > Pass thin archives from subdirectories directly to the linker, and
>> > remove the final archiving step.
>>
>> This seems like a good improvement. As far as I remember, it was slower
>> to do the final link without the index built. Maybe I was testing it
>> in a revision before moving those files into --whole-archive? If there
>> is no slowdown, then I have no objection.
>
>
> Thanks for the review.
>
>
> I measured the performance of scripts/link-vmlinux.sh with 'perf stat'.
> (20 times for each)
>
>
>
> Before this patch:
>
> Performance counter stats for 'make vmlinux' (20 runs):
>
> 5.266796537 seconds time elapsed
> ( +- 0.12% )
>
>
>
> After this patch:
>
> Performance counter stats for 'make vmlinux' (20 runs):
>
> 4.945576395 seconds time elapsed
>
>
>
>
> So, the performance is slightly better.
>
> Maybe, does omitting the 'ar' save some time?
Wow yeah that's a good speedup and simplification to boot. Thanks for
checking it.
> Anyway, this commit is good.
Yes, it's a good improvement.
Thanks,
Nick
prev parent reply other threads:[~2019-01-23 8:26 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2019-01-14 3:27 Masahiro Yamada
2019-01-14 3:27 ` [PATCH 2/2] kbuild: merge KBUILD_VMLINUX_{INIT,MAIN} into KBUILD_VMLINUX_OBJS Masahiro Yamada
2019-01-15 7:15 ` [PATCH 1/2] kbuild: remove top-level built-in.a Nicholas Piggin
2019-01-15 9:01 ` Masahiro Yamada
2019-01-23 8:26 ` Nicholas Piggin [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1548231946.lwdxf373y2.astroid@bobo.none \
--to=npiggin@gmail.com \
--cc=linux-kbuild@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=sfr@canb.auug.org.au \
--cc=yamada.masahiro@socionext.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®